#ifndef H_CDW_VERIFY_WIZARD
#define H_CDW_VERIFY_WIZARD

#include "main.h"

cdw_id_t cdw_verify_wizard(void);


#endif /* H_CDW_VERIFY_WIZARD */
